class Mailer:

    def __init__(self, settings):
        self.domain_name = settings['mailgun.domain_name']
        self.api_key = settings['mailgun.api_key']

    def send(self, email):
        import requests
        requests.post(
            "https://api.mailgun.net/v3/{}/messages".format(self.domain_name),
            auth=("api", self.api_key),
            data={
                "from": email['from'],
                "to": email['to'],
                "subject": email['subject'],
                "text": email['text']
            }
        )

def mailer(request):
    return Mailer(request.registry.settings)

def includeme(config):
    config.add_request_method(mailer, 'mailer', reify=True)



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

setup(
    name='pyramid_mailgun',
    version='0.0.1',
    packages=['pyramid_mailgun',],
    description='Mailgun integration for Pyramid framework',
    author='Evan Nook',
    author_email='evan@innonook.com',
    url='https://github.com/evannook/pyramid_mailgun',
    license='MIT',
    long_description=open('README.txt').read(),
    install_requires = ['requests'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ]
)
